@@ -206,6 +206,14 @@ CubicSDR::CubicSDR() : frequency(0), offset(0), ppm(0), snap(1), sampleRate(DEFA
         shuttingDown.store(false);
         fdlgTarget = FrequencyDialog::FDIALOG_TARGET_DEFAULT;
         stoppedDev = nullptr;
+
+        //set OpenGL configuration:
+        m_glContextAttributes = new wxGLContextAttrs();
+        
+        wxGLContextAttrs glSettings;
+        glSettings.PlatformDefaults().EndList();
+
+        *m_glContextAttributes = glSettings;
 }
 
 bool CubicSDR::OnInit() {
@@ -484,11 +492,10 @@ int CubicSDR::OnExit() {
     delete m_glContext;
     m_glContext = nullptr;
 
-    std::cout << "Application termination complete." << std::endl << std::flush;
-
-#ifdef __APPLE__
+    //
     AudioThread::deviceCleanup();
-#endif
+
+    std::cout << "Application termination complete." << std::endl << std::flush;
 
     return wxApp::OnExit();
 }
@@ -496,13 +503,18 @@ int CubicSDR::OnExit() {
 PrimaryGLContext& CubicSDR::GetContext(wxGLCanvas *canvas) {
     PrimaryGLContext *glContext;
     if (!m_glContext) {
-        m_glContext = new PrimaryGLContext(canvas, NULL);
+        m_glContext = new PrimaryGLContext(canvas, NULL, GetContextAttributes());
     }
     glContext = m_glContext;
 
     return *glContext;
 }
 
+wxGLContextAttrs* CubicSDR::GetContextAttributes() {
+   
+    return m_glContextAttributes;
+}
+
 void CubicSDR::OnInitCmdLine(wxCmdLineParser& parser) {
     parser.SetDesc (commandLineInfo);
     parser.SetSwitchChars (wxT("-"));
